@@ -6,7 +6,7 @@ use vars qw(@ISA $VERSION);
 use Storable qw(nfreeze thaw);
 
 @ISA = qw(DynaLoader);
-$VERSION = '0.05';
+$VERSION = '0.10';
 
 bootstrap Parallel::MPI::Simple;
 
@@ -15,7 +15,7 @@ sub import {
     my $call = (caller())[0];
     no strict 'refs';
     # subs (MPI_ function calls)
-    foreach (qw(Init Finalize COMM_WORLD Comm_rank Comm_size
+    foreach (qw(Init Finalize COMM_WORLD ANY_SOURCE Comm_rank Comm_size
 		Recv Send Barrier Bcast Gather
 		Scatter Allgather Alltoall Reduce
 		Comm_compare Comm_dup Comm_free Comm_split
@@ -295,6 +295,8 @@ destination, tag and comminicator will be delivered in the order in
 which they were sent.  No other guarantees of timeliness or ordering
 can be given.  If needed, use C<MPI_Barrier>.
 
+C<$source> can be C<MPI_ANY_SOURCE> which will do what it says.
+
 =cut
 
 sub Recv {
